@@ -1,14 +1,28 @@
-__version__ = "0.0.3"
+__version__ = "0.0.6"
 
 from ji_auth.canvas import get_canvas_token
 from ji_auth.joj import get_joj_sid
-from typer import Typer, echo, Option
+from typer import Typer, echo, Option, Exit, main
 import asyncio
 import sys
 
 app = Typer(add_completion=False)
 
 
+def version_callback(value: bool) -> None:
+    if value:
+        echo(__version__)
+        raise Exit()
+
+
+def show_version(
+    version: bool = Option(
+        None, "--version", callback=version_callback, help="Show version."
+    ),
+) -> None:
+    pass
+
+
 @app.command("joj")
 def echo_joj_sid(
     disable_mask: bool = Option(
@@ -37,7 +51,9 @@ def echo_canvas_token(
     Get a newly generated token from Canvas.
     """
     try:
-        res = asyncio.get_event_loop().run_until_complete(get_canvas_token(not disable_mask))
+        res = asyncio.get_event_loop().run_until_complete(
+            get_canvas_token(not disable_mask)
+        )
         echo("Here is your token:", file=sys.stderr)
         echo(res)
     except Exception as e:
@@ -45,5 +61,12 @@ def echo_canvas_token(
         echo(e, file=sys.stderr)
 
 
+app = main.get_group(app)
+parameters = main.get_params_from_function(show_version)
+(version_param,) = parameters.values()
+click_version_param, _ = main.get_click_param(version_param)
+app.params.append(click_version_param)
+
+
 if __name__ == "__main__":
     app()
